.. _introduction:

Locan is a python-based library with code for analyzing single-molecule
localization data. Such data is typically generated in fluorescence-based super-resolution microscopy methods.
Single-molecule localization microscopy (SMLM) techniques rely on finding the position of single-molecule
emitters in time and space and reconstructing a super-resolved image or movie.
The generated localizations are analyzed point-by-point for statistical and structural insight.
